# District 5 
Python 3 DB-API and SQLAlchemy dialect to connect to [duckdb](https://duckdb.org) over http i.e ( [Radio-Duck](https://github.com/jaihind213/radio-duck) )

(inspiried by my favourite movie [Mighty ducks](https://www.imdb.com/title/tt0104868))

# todo:
1. logging
2. pydocs
3. code formatting